
/**

GNU-DiaboloSimulator : ce programme permet de simuler des siteswaps au
diabolo.

Copyright (C) 2012 Frédéric MICOUT - fred@sujets-libres.fr
Tous droits réservés.

Ce programme est un logiciel libre ; vous pouvez le redistribuer ou le
modifier suivant les termes de la “GNU General Public License” telle que
publiée par la Free Software Foundation : soit la version 3 de cette
licence, soit (à votre gré) toute version ultérieure.

Ce programme est distribué dans l’espoir qu’il vous sera utile, mais SANS
AUCUNE GARANTIE : sans même la garantie implicite de COMMERCIALISABILITÉ
ni d’ADÉQUATION À UN OBJECTIF PARTICULIER. Consultez la Licence Générale
Publique GNU pour plus de détails.

Vous devriez avoir reçu une copie de la Licence Générale Publique GNU avec
ce programme ; si ce n’est pas le cas, consultez :
<http://www.gnu.org/licenses/>.

**/

#include "animation.h"
#include "qmovablegraphicsview.h"
#include <QGraphicsScene>
#include <QGraphicsView>
#include <iostream>

using namespace std;

Animation::Animation(QWidget *parent) :
        QWidget(parent)
{
    int i;

    high = true;
    tempsBase = 900;
    droitier = true;
    pourcentageTempsAVide = 50;
    pourcentageTempsDeuxDiabsCorde = 8;

    QString style;
    for(i=0;i<9;i++)
    {
        couleurDiabolos.push_back(QColor((255*(2-i/3))%256,(80*i)%256,(255*(i/3))%256));
    }
}

void Animation::textChanged(QString texte)
{
    titre = texte;
}

void Animation::siteswapChanged(QList<int> siteS)
{
    siteswapActuel = siteS;
}

void Animation::tempsDeDepartParObjets(QList<int> tempsDeObj)
{
    retardObjet = tempsDeObj;
}

void Animation::sequenceParObjetChange(QList<QList<int> > parObjet)
{
    siteswapActuelParObjet = parObjet;
}

void Animation::siteswapValide(bool valide)
{
    affichageAutorise = valide;
}

void Animation::siteswapNbObjets(int nbObj)
{
    nombreObjets = nbObj;
}



void Animation::setHigh()
{
    high = true;
}

void Animation::setLow()
{
    high = false;
}



void Animation::setDroitier()
{
    droitier = true;
}

void Animation::setGaucher()
{
    droitier = false;
}


void Animation::setTempsBase(int tBase)
{
    tempsBase = tBase;
}


void Animation::setPourcentageTempsAVide(int aVide)
{
    pourcentageTempsAVide = aVide;
}

void Animation::setAnimation()
{

    if(!affichageAutorise)
    {

        QDialog *anim = new QDialog;
        anim->setWindowTitle("erreur");

        QLabel *lab1 = new QLabel;
        lab1->setText(tr("Siteswap non valide"));
        lab1->setFont(QFont("Times", 12, QFont::DemiBold));

        QVBoxLayout *layout = new QVBoxLayout();
        layout->addWidget(lab1);
        anim->setLayout(layout);
        anim->show();
    }

    else
    {
        int i,j;

        int tJmax = 3;
        for(i=0;i<siteswapActuel.size();i++) if(siteswapActuel.at(i)>tJmax) tJmax = siteswapActuel.at(i);
        float tempsJongleMax = tJmax;


        // Calcul des temps de l'animation à construire
        int tempsAVide = tempsBase*pourcentageTempsAVide/100; // Le temps à vide est uniquement valable en "high", entre le moment où on lance un diabolo et le moment où on réceptionne le suivant
        int tempsBaseCorde = tempsBase/2;
        int tempsJongleMaxCorde = (tempsJongleMax+1)/2;
        int tempsDeuxDiabsCorde = tempsBase*pourcentageTempsDeuxDiabsCorde/100; // Le temps durant lequel on a deux diabolos dans la corde est uniquement valable en "low"

        int hauteurPxMax; // hauteur max en pixel que peut avoir l'un des diabolos
        int dimensionDiab;
        int decalageMaxTrajectoireDiab; // décalage de la trajectoire du diabolo par rapport à l'axe médian vertical du jongleur
        int decalageXJongleur; // décalage de l'axe médian vertical du jongleur par rapport au bord gauche de la fenêtre
        int decalageYJongleur; // décalage de l'axe médian horizontal du jongleur par rapport au bord haut de la fenêtre
        if(high)
        {
            hauteurPxMax = 450 + 20*(tempsJongleMax);
            dimensionDiab = 240/(tempsJongleMax*tempsJongleMax);
            decalageMaxTrajectoireDiab = 800/(tempsJongleMax*tempsJongleMax);
            decalageXJongleur = 200;
            decalageYJongleur = 580 + 10*(tempsJongleMax) - decalageMaxTrajectoireDiab/2 - dimensionDiab/2;
        }
        else
        {
            hauteurPxMax = 360 + 20*(tempsJongleMaxCorde);
            dimensionDiab = 240/(tempsJongleMaxCorde*tempsJongleMaxCorde);
            decalageMaxTrajectoireDiab = 800/(tempsJongleMaxCorde*tempsJongleMaxCorde);
            decalageXJongleur = 200;
            decalageYJongleur = 530 + 10*(tempsJongleMaxCorde) - decalageMaxTrajectoireDiab/2 - dimensionDiab/2;
        }

        QList<int> tempsEnCours; // Contient tout les temps de lancé successifs pour un diabolo



        // Fenêtre QDialog qui va contenir l'animation
        QDialog *anim = new QDialog;
        anim->setWindowTitle(titre);
        anim->setMinimumSize(400,700);
        //anim->setMaximumSize(400,700);

        QPalette palette;
        palette.setBrush(QPalette::Window, QColor(50,50,50,255));
        anim->setPalette(palette);


        // Création de l'animation principale (qui sera composée de plusieurs animations s'éxécutant en parallèle)
        QParallelAnimationGroup* animationParallele = new QParallelAnimationGroup;

        // Création des conteneurs
        QList<QGraphicsScene *> leJongleur; // Pour dessiner chaque partie du jongleur
        QList<QMovableGraphicsView *> leJongleurContenant; // "Boite" contenant chaque partie du jongleur
        QList<QGraphicsScene *> lesScenesList; // Pour dessiner chaque diabolo
        QList<QMovableGraphicsView *> graphicsViewList; // "Boite" contenant chaque diabolo créé
        QList<QSequentialAnimationGroup *> animationSequentielleAvecPause; // Animation complète sur X et Y d'un objet. Va inclure le temps de pause à effectuer une seule fois avant de lancer les différentes animations
        QList<QParallelAnimationGroup *> animationXY; // Animation partielle sur X et Y d'un objet (hors temps de pause). Sert à lier l'animation sur X et l'animation sur Y d'un objet.
        QList<QSequentialAnimationGroup *> SeqX; // Animation partielle sur X d'un diabolo (incluant tout les temps de lancé sur l'objet considéré)
        QList<QSequentialAnimationGroup *> SeqY; // Animation partielle sur Y d'un diabolo (incluant tout les temps de lancé sur l'objet considéré)
        QList<QPropertyAnimation *> animationAirX; // Va contenir une animation sur X pour un temps de lancé donné
        QList<QPropertyAnimation *> animationAirY; // Va contenir une animation sur Y pour un temps de lancé donné
        QList<QPropertyAnimation *> animationCordeX; // Va contenir une animation sur X pour un temps de lancé donné
        QList<QPropertyAnimation *> animationCordeY; // Va contenir une animation sur Y pour un temps de lancé donné

        cout<<endl;
        cout<<endl;


        // Création du jongleur corps immobile du jongleur (tête / tronc)

        QPen pen(QColor(65,65,65,255), 0);
        QBrush brush(QColor(65,65,65,255));

        leJongleur.push_back(new QGraphicsScene());
        leJongleur.at(0)->addEllipse(QRectF(0, 0 , 1.6*dimensionDiab, 1.6*dimensionDiab),pen,brush);
        leJongleurContenant.push_back(new QMovableGraphicsView());
        leJongleurContenant.at(0)->setFixedSize(1.8*dimensionDiab,1.8*dimensionDiab);
        leJongleurContenant.at(0)->move(decalageXJongleur - 0.8*dimensionDiab,decalageYJongleur - 2*dimensionDiab);

        leJongleur.push_back(new QGraphicsScene());
        leJongleur.at(1)->addRect(QRectF(0.2*dimensionDiab, 0 + 2*dimensionDiab, 2*dimensionDiab, 4*dimensionDiab),pen,brush);
        leJongleurContenant.push_back(new QMovableGraphicsView());
        leJongleurContenant.at(1)->setFixedSize(2.1*dimensionDiab,4.1*dimensionDiab);
        leJongleurContenant.at(1)->move(decalageXJongleur - dimensionDiab,decalageYJongleur);

        for(i=0;i<leJongleurContenant.size();i++)
        {
            leJongleurContenant.at(i)->setRenderHints(QPainter::Antialiasing);
            leJongleurContenant.at(i)->setParent(anim);
            leJongleurContenant.at(i)->setFrameStyle(0);
            leJongleurContenant.at(i)->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
            leJongleurContenant.at(i)->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
            leJongleurContenant.at(i)->setStyleSheet("background: transparent");
            leJongleurContenant.at(i)->setScene(leJongleur.at(i));
        }





        // Le traitement est effectué sur chaque objet jonglé
        for(i=0;i<nombreObjets;i++)
        {

            // Création du dessin du diabolo
            lesScenesList.push_back(new QGraphicsScene());
            //lesScenesList.at(i)->addEllipse(QRectF(200, 0, dimensionDiab, dimensionDiab),QPen(QColor((255*(2-i/3))%256,(80*i)%256,(255*(i/3))%256,255)),QBrush(QColor((255*(2-i/3))%256,(80*i)%256,(255*(i/3))%256,255)));
            lesScenesList.at(i)->addEllipse(QRectF(200, 0, dimensionDiab, dimensionDiab),QPen(QColor(couleurDiabolos.at(i).red(),couleurDiabolos.at(i).green(),couleurDiabolos.at(i).blue(),255)),QBrush(QColor(couleurDiabolos.at(i).red(),couleurDiabolos.at(i).green(),couleurDiabolos.at(i).blue(),255)));
            if(tJmax<6 || !high) lesScenesList.at(i)->addEllipse(QRectF((dimensionDiab/2)-dimensionDiab/10+200, (dimensionDiab/2)-dimensionDiab/10, dimensionDiab/5, dimensionDiab/5),QPen(QColor(0,0,0,255)),QBrush(QColor(0,0,0,255)));

            // Création de la "boite" contenant le diabolo
            graphicsViewList.push_back(new QMovableGraphicsView());
            graphicsViewList.at(i)->setRenderHints(QPainter::Antialiasing);
            graphicsViewList.at(i)->setFixedSize(dimensionDiab,dimensionDiab);
            graphicsViewList.at(i)->setFrameStyle(0);
            graphicsViewList.at(i)->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
            graphicsViewList.at(i)->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
            graphicsViewList.at(i)->setStyleSheet("background: transparent");
            graphicsViewList.at(i)->setScene(lesScenesList.at(i));

            // Création des nouvelles séquences appelées à contenir l'une et l'autre des animations sur chaque axe (partie en boucle complète)
            SeqX.push_back(new QSequentialAnimationGroup());
            SeqY.push_back(new QSequentialAnimationGroup());

            // Création des animations à utiliser pour un temps de lancé donné
            QList<QPropertyAnimation *> animatCorde1X;
            QList<QPropertyAnimation *> animatCorde1Y;
            QList<QPropertyAnimation *> animatAirX;
            QList<QPropertyAnimation *> animatAirY;
            QList<QPropertyAnimation *> animatCorde2X;
            QList<QPropertyAnimation *> animatCorde2Y;

            // Création de la pause à ajouter au départ de l'animation pour le diabolo considéré
            QPropertyAnimation *pauseAnimation = new QPropertyAnimation(graphicsViewList.at(i), "pos");

            //
            animationXY.push_back(new QParallelAnimationGroup());

            animationAirX.push_back(new QPropertyAnimation());
            animationAirY.push_back(new QPropertyAnimation());
            animationCordeX.push_back(new QPropertyAnimation());
            animationCordeY.push_back(new QPropertyAnimation());

            tempsEnCours.clear();


            for(j=0;j<siteswapActuelParObjet.at(i).size();j++)
            {
                tempsEnCours.push_back(siteswapActuelParObjet.at(i).at(j));


                std::cout<<siteswapActuelParObjet.at(i).at(j)<< " " ;

                animatCorde1X.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posX"));
                animatCorde1Y.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posY"));
                animatAirX.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posX"));
                animatAirY.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posY"));
                animatCorde2X.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posX"));
                animatCorde2Y.push_back(new QPropertyAnimation(graphicsViewList.at(i), "posY"));


                // High
                if(high)
                {

                    if(siteswapActuelParObjet.at(i).at(j) == 1)
                    {
                        // Corde 1
                        animatCorde1X.at(j)->setDuration((tempsBase-tempsAVide/2)/4);
                        animatCorde1Y.at(j)->setDuration((tempsBase-tempsAVide/2)/4);

                        // Air
                        animatAirX.at(j)->setDuration((tempsBase+tempsAVide/2)/2);
                        animatAirY.at(j)->setDuration((tempsBase+tempsAVide/2)/2);
                        animatAirY.at(j)->setKeyValueAt(0.5, decalageYJongleur - 1.1*decalageMaxTrajectoireDiab);

                        // Corde 2
                        animatCorde2X.at(j)->setDuration((tempsBase-tempsAVide/2)/4);
                        animatCorde2Y.at(j)->setDuration((tempsBase-tempsAVide/2)/4);
                    }

                    else
                    {
                        // Corde 1
                        animatCorde1X.at(j)->setDuration((tempsBase-tempsAVide)/2);
                        animatCorde1Y.at(j)->setDuration((tempsBase-tempsAVide)/2);

                        // Air
                        animatAirX.at(j)->setDuration((tempsEnCours.at(j)-1)*tempsBase+tempsAVide);
                        animatAirY.at(j)->setDuration((tempsEnCours.at(j)-1)*tempsBase+tempsAVide);
                        animatAirY.at(j)->setKeyValueAt(0.5, decalageYJongleur -(tempsEnCours.at(j)*tempsEnCours.at(j)*(hauteurPxMax/(tempsJongleMax*tempsJongleMax))));

                        // Corde 2
                        animatCorde2X.at(j)->setDuration((tempsBase-tempsAVide)/2);
                        animatCorde2Y.at(j)->setDuration((tempsBase-tempsAVide)/2);
                    }


                    // Corde 1
                    animatCorde1X.at(j)->setKeyValueAt(0, decalageXJongleur - dimensionDiab/2);
                    if (droitier) animatCorde1X.at(j)->setKeyValueAt(1, decalageXJongleur + decalageMaxTrajectoireDiab - dimensionDiab/2);
                    else animatCorde1X.at(j)->setKeyValueAt(1, decalageXJongleur - decalageMaxTrajectoireDiab - dimensionDiab/2);
                    animatCorde1X.at(j)->setLoopCount(1);

                    animatCorde1Y.at(j)->setKeyValueAt(0, decalageYJongleur + 1.1*decalageMaxTrajectoireDiab);
                    animatCorde1Y.at(j)->setKeyValueAt(1, decalageYJongleur);
                    animatCorde1Y.at(j)->setLoopCount(1);
                    animatCorde1Y.at(j)->setEasingCurve(QEasingCurve::InCubic);

                    // Air
                    animatAirX.at(j)->setKeyValueAt((droitier+1)%2, decalageXJongleur + decalageMaxTrajectoireDiab - dimensionDiab/2);
                    animatAirX.at(j)->setKeyValueAt(droitier, decalageXJongleur - decalageMaxTrajectoireDiab - dimensionDiab/2);
                    animatAirX.at(j)->setLoopCount(1);

                    animatAirY.at(j)->setKeyValueAt((droitier+1)%2, decalageYJongleur);
                    animatAirY.at(j)->setKeyValueAt(droitier, decalageYJongleur);
                    animatAirY.at(j)->setLoopCount(1);
                    animatAirY.at(j)->setEasingCurve(QEasingCurve::OutInQuad);

                    // Corde 2
                    if (droitier) animatCorde2X.at(j)->setKeyValueAt(0, decalageXJongleur - decalageMaxTrajectoireDiab - dimensionDiab/2);
                    else animatCorde2X.at(j)->setKeyValueAt(0, decalageXJongleur + decalageMaxTrajectoireDiab - dimensionDiab/2);
                    animatCorde2X.at(j)->setKeyValueAt(1, decalageXJongleur - dimensionDiab/2);
                    animatCorde2X.at(j)->setLoopCount(1);

                    animatCorde2Y.at(j)->setKeyValueAt(0, decalageYJongleur);
                    animatCorde2Y.at(j)->setKeyValueAt(1, decalageYJongleur + 1.1*decalageMaxTrajectoireDiab);
                    animatCorde2Y.at(j)->setLoopCount(1);
                    animatCorde2Y.at(j)->setEasingCurve(QEasingCurve::OutCubic);
                }


                // Low
                else
                {

                    if(siteswapActuelParObjet.at(i).at(j) == 1)
                    {
                        // Corde 1
                        animatCorde1X.at(j)->setDuration(tempsBaseCorde/4);
                        animatCorde1Y.at(j)->setDuration(tempsBaseCorde/4);
                        animatCorde1X.at(j)->setKeyValueAt(1, decalageXJongleur - dimensionDiab/2);
                        animatCorde1Y.at(j)->setKeyValueAt(1, decalageYJongleur + decalageMaxTrajectoireDiab);

                        // Air
                        animatAirX.at(j)->setDuration(tempsBaseCorde/2);
                        animatAirY.at(j)->setDuration(tempsBaseCorde/2);
                        animatAirX.at(j)->setKeyValueAt(0, decalageXJongleur - dimensionDiab/2);
                        animatAirX.at(j)->setKeyValueAt(1, decalageXJongleur - dimensionDiab/2);
                        animatAirY.at(j)->setKeyValueAt(0, decalageYJongleur + decalageMaxTrajectoireDiab);
                        animatAirY.at(j)->setKeyValueAt(1, decalageYJongleur + decalageMaxTrajectoireDiab);

                        // Corde 2
                        animatCorde2X.at(j)->setDuration(tempsBaseCorde/4);
                        animatCorde2Y.at(j)->setDuration(tempsBaseCorde/4);
                        animatCorde2X.at(j)->setKeyValueAt(0, decalageXJongleur - dimensionDiab/2);
                        animatCorde2Y.at(j)->setKeyValueAt(0, decalageYJongleur + decalageMaxTrajectoireDiab);
                    }


                    else
                    {
                        // Corde 1
                        animatCorde1X.at(j)->setDuration((tempsBaseCorde+tempsDeuxDiabsCorde)/2);
                        animatCorde1Y.at(j)->setDuration((tempsBaseCorde+tempsDeuxDiabsCorde)/2);
                        if (droitier) animatCorde1X.at(j)->setKeyValueAt(1, decalageXJongleur + decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        else animatCorde1X.at(j)->setKeyValueAt(1, decalageXJongleur - decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        animatCorde1Y.at(j)->setKeyValueAt(1, decalageYJongleur);

                        // Air
                        animatAirX.at(j)->setDuration((tempsEnCours.at(j)-1)*tempsBaseCorde-tempsDeuxDiabsCorde);
                        animatAirY.at(j)->setDuration((tempsEnCours.at(j)-1)*tempsBaseCorde-tempsDeuxDiabsCorde);
                        animatAirX.at(j)->setKeyValueAt((droitier+1)%2, decalageXJongleur + decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        animatAirX.at(j)->setKeyValueAt(droitier, decalageXJongleur - decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        animatAirY.at(j)->setKeyValueAt((droitier+1)%2, decalageYJongleur);
                        animatAirY.at(j)->setKeyValueAt(0.5, decalageYJongleur -(tempsEnCours.at(j)*tempsEnCours.at(j)*(hauteurPxMax/(4*tempsJongleMaxCorde*tempsJongleMaxCorde))));
                        animatAirY.at(j)->setKeyValueAt(droitier, decalageYJongleur);

                        // Corde 2
                        animatCorde2X.at(j)->setDuration((tempsBaseCorde+tempsDeuxDiabsCorde)/2);
                        animatCorde2Y.at(j)->setDuration((tempsBaseCorde+tempsDeuxDiabsCorde)/2);
                        if (droitier) animatCorde2X.at(j)->setKeyValueAt(0, decalageXJongleur - decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        else animatCorde2X.at(j)->setKeyValueAt(0, decalageXJongleur + decalageMaxTrajectoireDiab*2/3 - dimensionDiab/2);
                        animatCorde2Y.at(j)->setKeyValueAt(0, decalageYJongleur);

                    }

                    // Corde 1
                    animatCorde1X.at(j)->setKeyValueAt(0, decalageXJongleur - dimensionDiab/2);
                    animatCorde1X.at(j)->setLoopCount(1);
                    animatCorde1Y.at(j)->setKeyValueAt(0, decalageYJongleur + decalageMaxTrajectoireDiab);
                    animatCorde1Y.at(j)->setLoopCount(1);
                    animatCorde1Y.at(j)->setEasingCurve(QEasingCurve::InCubic);

                    // Air
                    animatAirX.at(j)->setLoopCount(1);
                    animatAirY.at(j)->setLoopCount(1);
                    animatAirY.at(j)->setEasingCurve(QEasingCurve::OutInQuad);

                    // Corde 2
                    animatCorde2X.at(j)->setKeyValueAt(1, decalageXJongleur - dimensionDiab/2);
                    animatCorde2X.at(j)->setLoopCount(1);
                    animatCorde2Y.at(j)->setKeyValueAt(1, decalageYJongleur + decalageMaxTrajectoireDiab);
                    animatCorde2Y.at(j)->setLoopCount(1);
                    animatCorde2Y.at(j)->setEasingCurve(QEasingCurve::OutCubic);
                }



                SeqX.at(i)->addAnimation(animatCorde1X.at(j));
                SeqX.at(i)->addAnimation(animatAirX.at(j));
                SeqX.at(i)->addAnimation(animatCorde2X.at(j));

                SeqY.at(i)->addAnimation(animatCorde1Y.at(j));
                SeqY.at(i)->addAnimation(animatAirY.at(j));
                SeqY.at(i)->addAnimation(animatCorde2Y.at(j));



            }
            std::cout<<endl;



            SeqX.at(i)->setLoopCount(1);
            SeqY.at(i)->setLoopCount(1);

            animationXY.at(i)->addAnimation(SeqX.at(i));
            animationXY.at(i)->addAnimation(SeqY.at(i));
            animationXY.at(i)->setLoopCount(-1);




            // Pause
            if(high) pauseAnimation->setDuration(tempsBase*retardObjet.at(i));
            else pauseAnimation->setDuration(tempsBaseCorde*retardObjet.at(i));
            pauseAnimation->setKeyValueAt(0,QPointF(120,500));
            pauseAnimation->setKeyValueAt(1,QPointF(120,500));
            pauseAnimation->setLoopCount(1);


            animationSequentielleAvecPause.push_back(new QSequentialAnimationGroup());
            animationSequentielleAvecPause.at(i)->addAnimation(pauseAnimation);
            animationSequentielleAvecPause.at(i)->addAnimation(animationXY.at(i));
            animationSequentielleAvecPause.at(i)->setLoopCount(1);

            animationParallele->addAnimation(animationSequentielleAvecPause.at(i));

        }

        animationParallele->setLoopCount(1);
        animationParallele->start();




        //leJongleurContenant.at(0)->show();

        QVBoxLayout *layout = new QVBoxLayout();


        for(i=0;i<graphicsViewList.size();i++)
        {
            layout->addWidget(graphicsViewList.at(i));
        }

        anim->setLayout(layout);
        anim->show();//Maximized();

    }

}

void Animation::setCouleurDiabolos(QList<QColor> couleur)
{
    int i;

    for(i=0;i<couleur.size();i++)
    {
        couleurDiabolos.replace(i,couleur.at(i));
    }

}
