
/**

GNU-DiaboloSimulator : ce programme permet de simuler des siteswaps au
diabolo.

Copyright (C) 2012 Frédéric MICOUT - fred@sujets-libres.fr
Tous droits réservés.

Ce programme est un logiciel libre ; vous pouvez le redistribuer ou le
modifier suivant les termes de la “GNU General Public License” telle que
publiée par la Free Software Foundation : soit la version 3 de cette
licence, soit (à votre gré) toute version ultérieure.

Ce programme est distribué dans l’espoir qu’il vous sera utile, mais SANS
AUCUNE GARANTIE : sans même la garantie implicite de COMMERCIALISABILITÉ
ni d’ADÉQUATION À UN OBJECTIF PARTICULIER. Consultez la Licence Générale
Publique GNU pour plus de détails.

Vous devriez avoir reçu une copie de la Licence Générale Publique GNU avec
ce programme ; si ce n’est pas le cas, consultez :
<http://www.gnu.org/licenses/>.

**/

#include "siteswap.h"
#include <iostream>

using namespace std;

SiteSwap::SiteSwap(QWidget *parent) :
    QWidget(parent)
{

}

// Vérification validité siteswap
bool SiteSwap::getValidite()
{
    bool valide = true;
    int i,j;

    switch (vecteurDeSaisie.size())
    {
    case 0:
        valide = false;
        break;

    case 1:
        valide = true;
        break;

    default:
        // Préparation
        int tmp = 0;

        // test 1 : la séquence est jonglée avec un nombre entier d'objets
        for(i=0;i<vecteurDeSaisie.size();i++) tmp += vecteurDeSaisie.value(i);
        if(tmp % vecteurDeSaisie.size() != 0) valide = false;

        // test 2 : permutation
        vecteurDePermutation.clear();
        for(i=0;i<vecteurDeSaisie.size();i++)
        {
            vecteurDePermutation.push_back((vecteurDeSaisie.value(i) + i) % vecteurDeSaisie.size());
            if(i!=0)
            {
                for(j=0;j<i;j++)
                {
                    if(vecteurDePermutation.value(j) == vecteurDePermutation.value(i)) valide = false;
                }
            }
        }
        break;
    }

    emit getValiditeSequence(valide);
    return valide;
}

int SiteSwap::getNbObjets()
{
    int nbObj = 0;
    int tmp = 0;
    int i;

    if(getValidite())
    {
        for(i=0;i<vecteurDeSaisie.size();i++) tmp += vecteurDeSaisie.value(i);
        if(vecteurDeSaisie.size() != 0) nbObj = tmp/vecteurDeSaisie.size();
    }


    emit getNbObjetsSequence(nbObj);
    return nbObj;
}

QList<QList<int> > SiteSwap::getSeqParObj()
{
    int i,j,k;
    QList<int> positionDansSiteswap;
    int positionSuivanteDansSiteswap;
    bool sequencePeriodique;
    QList<QList<int> > sequenceParObjet;
    QList<bool> positionLibreVecteurSaisie; // à utiliser lors de l'initialisation de la position initiale de l'objet dans le siteswap
    QList<int> sequence;
    QList<int> sequenceTemporaire;

    int tJmax = 1;
    for(i=0;i<vecteurDeSaisie.size();i++) if(vecteurDeSaisie.at(i)>tJmax) tJmax = vecteurDeSaisie.at(i);

    for(i=0;i<10;i++) positionLibreVecteurSaisie.push_back(true);

    for(i=0;i<nbObjets;i++)
    {
        // Initialiser les séquences (normale et temporaire)
        sequence.clear();
        sequenceTemporaire.clear();


        // Pour l'objet en cours, initialisation de la position initiale dans le siteswap
        for(j=0;j<positionLibreVecteurSaisie.size();j++)
        {
            cout<<positionLibreVecteurSaisie.at(j);
            if(vecteurDeSaisie.at(j%vecteurDeSaisie.size()) == 0)
            {
                positionLibreVecteurSaisie.replace(j,false);
            }

            else if(positionLibreVecteurSaisie.at(j))
            {
                positionDansSiteswap.push_back(j);
                do
                {
                    // Elimination des positions qui ne peuvent plus accueillir la position initiale d'un nouvel objet
                    positionLibreVecteurSaisie.replace(j,false);
                    j += vecteurDeSaisie.at(j%vecteurDeSaisie.size());
                }
                while(j<positionLibreVecteurSaisie.size());
            }
        }


        // Détermination d'une séquence périodique pour chaque objet
        sequencePeriodique = false;

        positionSuivanteDansSiteswap = positionDansSiteswap.at(i);

        j = 0;

        do
        {
            sequenceTemporaire.push_back(vecteurDeSaisie.at( positionSuivanteDansSiteswap % vecteurDeSaisie.size() ));
            positionSuivanteDansSiteswap = (positionSuivanteDansSiteswap + vecteurDeSaisie.at( positionSuivanteDansSiteswap % vecteurDeSaisie.size() ) )  % vecteurDeSaisie.size();

            j++; // Va compter le nombre d'itérations effectuées dans la boucle

            if((j > vecteurDeSaisie.size()) && (j%2 == 0))
            {

                sequencePeriodique = true;

                // Une fois un certain nombre d'enregistrements ajoutés à la séquence temporaire, on cherche à déterminer si cette séquence est périodique (et qu'elle se répète au moins deux fois).
                for(k=0;k<j/2;k++)
                {
                    if(sequenceTemporaire.at(k) != sequenceTemporaire.at(k+j/2)) sequencePeriodique = false;
                }
            }
        }
        while(!sequencePeriodique);

        // Pour chaque objet jonglable, on entre la séquence optimale
        sequence = sequenceTemporaire;
        sequenceParObjet.push_back(sequenceTemporaire);

        for(j=0;j<sequenceTemporaire.size();j++)
        {
            cout<<sequenceTemporaire.at(j)<<" ";
        }
        cout<<endl;
    }
    cout<<endl;

    // retourne la liste contenant la première position dans le siteswap pour chaque objet (diabolo)
    emit getPremierePosition(positionDansSiteswap);

    // retourner le QList<QList<int>
    return sequenceParObjet;
}


void SiteSwap::textChanged(QString texte)
{
    int i;
    QString texteNettoye;

    texte.remove(QRegExp("[^\\d]"));
    texteNettoye = texte;

    // Mémorisation du siteswap
    vecteurDeSaisie.clear(); // on vide le vecteur contenant le siteswap (int)
    for(i=0;i<texteNettoye.size();i++) vecteurDeSaisie.push_back(texteNettoye.at(i).digitValue());

    nbObjets = getNbObjets();

    // Emission des signaux une fois la séquence nettoyée et transformée en interger
    emit getSequence(vecteurDeSaisie); // note : sera uniquement utlisé pour déterminer le temps de lancé max par l'animation
    emit getLabNbObjets(QString::number(nbObjets)); // renvoi une chaine affichant le nombre d'objets de la séquence en cours. Ordonne le calcul du nombre d'objets (et donc, l'émission du signal correspondant au nombre d'objet (int))
    emit getSequenceParObjet(getSeqParObj());

}
